Index: webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h |
diff --git a/webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h b/webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h |
index 91b9fc94a538bfb80fc041f40de7d6e8ae258121..f979655c89d00ad21167b13c573805b026bd4c54 100644 |
--- a/webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h |
+++ b/webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h |
@@ -10,7 +10,7 @@ |
#import <UIKit/UIKit.h> |
-@class ARDMediaConstraintsModel; |
+@class ARDSettingsModel; |
NS_ASSUME_NONNULL_BEGIN |
/** |
@@ -22,10 +22,10 @@ NS_ASSUME_NONNULL_BEGIN |
* Creates new instance. |
* |
* @param style the table view style that should be used |
* @param mediaConstraintsModel model class for the media constraints settings. |
*/ |
- (instancetype)initWithStyle:(UITableViewStyle)style |
- mediaConstraintsModel:(ARDMediaConstraintsModel *)mediaConstraintsModel; |
+ settingsModel:(ARDSettingsModel *)settingsModel; |
#pragma mark - Unavailable |
@@ -22,10 +22,10 @@ NS_ASSUME_NONNULL_BEGIN |
* |
* @param style the table view style that should be used |
- * @param mediaConstraintsModel model class for the media constraints settings. |
+ * @param settingsModel model class for the user settings. |
*/ |